/*
 * This is not a general-purpose snprintf replacement.
 * It works in this program because we know the largest buffer anywhere
 * is 8192 bytes.
 */

#include <stdio.h>
#include <stdarg.h>
#include <assert.h>

extern "C"
int vsnprintf(char *buf, size_t len, const char *fmt, va_list ap) {
    int ret;
    static char realbuf[16384];
    ret = vsprintf(realbuf, fmt, ap);
    assert(strlen(realbuf) <= 8192);
    assert(len <= 8192 && len>0);
    realbuf[len-1] = 0;
    strcpy(buf, realbuf);
    return ret;
}

extern "C"
int snprintf(char *buf, size_t len, const char *fmt, ...) {
    int ret;
    va_list ap;
    va_start(ap, fmt);
    ret = vsnprintf(buf, len, fmt, ap);
    va_end(ap);
    return ret;
}

