/*
 * Half-Baked Curses
 *
 * This implements a subset of the curses API in terms of the
 * semi-standard vt100/ANSI.SYS/xterm escape sequences. If you
 * have trouble with your normal curses, you might try this. 
 * Note that it does not optimize output very well; if you don't
 * have a fast link it'll probably be quite maddening.
 */

#ifndef _CURSES_H_
#define _CURSES_H_

/* this tells hbc.cc it's got the right include file. */
#define __HBC_CURSES

/* attributes */
#define A_BOLD        0x100
#define A_REVERSE     0x200
#define A_DIM         0x400
#define COLOR_PAIR(n) ((n)<<12)

#define COLOR_BLACK   0
#define COLOR_RED     1
#define COLOR_GREEN   2
#define COLOR_YELLOW  3
#define COLOR_BLUE    4
#define COLOR_PURPLE  5
#define COLOR_CYAN    6
#define COLOR_WHITE   7

#ifdef __cplusplus
extern "C" {
#endif

    extern int COLS, LINES;     /* screen size */

    void erase(void);           /* clear virtual screen */
    void clear(void);           /* clear physical screen */
    void clrtoeol(void);        /* clear to end of line */

    void move(int y, int x);    /* move cursor */
    void addch(int ch);         /* print character */
    void addstr(const char *);  /* print string */
    void beep(void);            /* beep */

    void attron(int);           /* turn screen attribute on */
    void attroff(int);          /* turn screen attribute off */

    void refresh(void);         /* update screen */

    /* combo: move, then add */
    void mvaddch(int y, int x, int ch);
    void mvaddstr(int y, int x, const char *);

    void initscr(void);         /* set up */
    void cbreak(void);          /* cbreak mode */
    void noecho(void);          /* disable terminal echo */
    void endwin(void);          /* shut down */

    bool has_colors(void);      /* check for color support */
    void start_color(void);	/* set up color support */
    void init_pair(int n, int fg, int bg);  /* set up color combo */

#ifdef __cplusplus
}
#endif

#endif /* _CURSES_H_ */
