#include <string.h>
#include <assert.h>
#include "server.h"
#include "tile.h"

// tile names: A-Z and _
// special tile names: a-z and -
// tile numbers: 0-27

static const char tile_names[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ_";
static const char tile_specs[] = "abcdefghijklmnopqrstuvwxyz-";

int tile_isname(int tile) {
    return strchr(tile_names, tile)!=NULL;
}

int tile_isspec(int tile) {
    return strchr(tile_specs, tile)!=NULL;
}

int tile_name2num(int tile) {
    assert((tile>='A' && tile<='Z') || tile=='_');
    if (tile=='_') return 26;
    return tile-'A';
}

int tile_spec2num(int tile) {
    assert((tile>='a' && tile<='z') || tile=='-');
    if (tile=='-') return 26;
    return tile-'a';
}

int tile_num2name(int tile) {
    assert(tile>=0 && tile<NTILES);
    return tile_names[tile];
}

int tile_num2spec(int tile) {
    assert(tile>=0 && tile<NTILES);
    return tile_specs[tile];
}

int tile_name2spec(int tile) {
    return tile_num2spec(tile_name2num(tile));
}

int tile_spec2name(int tile) {
    return tile_num2name(tile_spec2num(tile));
}

int tilescore(int tile) {
    static const int tscores[NTILES] = {
	// ABC DEF GHI
	1, 3, 3, 2, 1, 4, 2, 4, 1,
	// JKL MNO PQR
	8, 5, 1, 3, 1, 1, 3, 10, 1,
	// STU VWX YZ_
	1, 1, 1, 4, 4, 8, 4, 10, 0,
    };
    if (tile_isname(tile)) tile = tile_name2num(tile);
    else tile = tile_spec2num(tile);
    assert(tile>=0 && tile<NTILES);
    return tscores[tile];
}
